@@ -77,7 +77,7 @@ class TelegramQueue:
         address_filters: Optional[List[AddressFilter]] = None,
         group_addresses: Optional[List[GroupAddress]] = None,
         match_for_outgoing: bool = False,
-    ) -> Callback:
+    ) -> "TelegramQueue.Callback":
         """Register callback for a telegram being received from KNX bus."""
         callback = TelegramQueue.Callback(
             telegram_received_cb,
@@ -88,7 +88,9 @@ class TelegramQueue:
         self.telegram_received_cbs.append(callback)
         return callback
 
-    def unregister_telegram_received_cb(self, telegram_received_cb: Callback) -> None:
+    def unregister_telegram_received_cb(
+        self, telegram_received_cb: "TelegramQueue.Callback"
+    ) -> None:
         """Unregister callback for a telegram beeing received from KNX bus."""
         self.telegram_received_cbs.remove(telegram_received_cb)
 
@@ -117,15 +119,16 @@ class TelegramQueue:
                 self.xknx.telegrams.task_done()
                 break
 
-            try:
-                if telegram.direction == TelegramDirection.INCOMING:
+            if telegram.direction == TelegramDirection.INCOMING:
+                try:
                     await self.process_telegram_incoming(telegram)
+                except XKNXException as ex:
+                    logger.error("Error while processing incoming telegram %s", ex)
+                finally:
                     self.xknx.telegrams.task_done()
-                elif telegram.direction == TelegramDirection.OUTGOING:
-                    self.outgoing_queue.put_nowait(telegram)
-                    # self.xknx.telegrams.task_done() for outgoing is called in _outgoing_rate_limiter.
-            except XKNXException as ex:
-                logger.error("Error while processing telegram %s", ex)
+            elif telegram.direction == TelegramDirection.OUTGOING:
+                self.outgoing_queue.put_nowait(telegram)
+                # self.xknx.telegrams.task_done() for outgoing is called in _outgoing_rate_limiter.
 
     async def _outgoing_rate_limiter(self) -> None:
         """Endless loop for processing outgoing telegrams."""
