@@ -75,6 +75,11 @@ class BinarySensor(Device):
         """Iterate the devices RemoteValue classes."""
         yield self.remote_value
 
+    @property
+    def unique_id(self) -> Optional[str]:
+        """Return unique id for this device."""
+        return f"{self.remote_value.group_address_state}"
+
     def __del__(self) -> None:
         """Destructor. Cleaning up if this was not done before."""
         try:
