@@ -63,6 +63,11 @@ class Switch(Device):
                 pass
         super().__del__()
 
+    @property
+    def unique_id(self) -> Optional[str]:
+        """Return unique id for this device."""
+        return f"{self.switch.group_address}"
+
     @classmethod
     def from_config(cls, xknx: "XKNX", name: str, config: Dict[str, Any]) -> "Switch":
         """Initialize object from configuration structure."""
