@@ -1,4 +1,6 @@
 """Implementation of 3.17 Datapoint Types String."""
+from typing import Tuple
+
 from xknx.exceptions import ConversionError
 
 from .dpt import DPTBase
@@ -18,7 +20,7 @@ class DPTString(DPTBase):
     unit = ""
 
     @classmethod
-    def from_knx(cls, raw):
+    def from_knx(cls, raw: Tuple[int, ...]) -> str:
         """Parse/deserialize from KNX/IP raw data."""
         cls.test_bytesarray(raw)
         value = ""
@@ -28,7 +30,7 @@ class DPTString(DPTBase):
         return value
 
     @classmethod
-    def to_knx(cls, value):
+    def to_knx(cls, value: str) -> Tuple[int, ...]:
         """Serialize to KNX/IP raw data."""
         try:
             knx_value = str(value)
@@ -38,11 +40,11 @@ class DPTString(DPTBase):
             for character in knx_value:
                 raw.append(ord(character))
             raw.extend([0] * (cls.payload_length - len(raw)))
-            return raw
+            return tuple(raw)
         except ValueError:
             raise ConversionError("Could not serialize %s" % cls.__name__, value=value)
 
     @classmethod
-    def _test_boundaries(cls, value):
+    def _test_boundaries(cls, value: str) -> bool:
         """Test if value is within defined range for this object."""
         return len(value) <= cls.payload_length
