@@ -22,9 +22,7 @@ class TunnellingRequest(KNXIPBody):
     """Representation of a KNX Tunnelling Request."""
 
     # pylint: disable=too-many-instance-attributes
-
-    service_type = KNXIPServiceType.TUNNELLING_REQUEST
-
+    SERVICE_TYPE = KNXIPServiceType.TUNNELLING_REQUEST
     HEADER_LENGTH = 4
 
     def __init__(
