@@ -1,6 +1,6 @@
 """Module for handling values on the KNX bus."""
 # flake8: noqa
-from .remote_value import RemoteValue
+from .remote_value import GroupAddressesType, RemoteValue
 from .remote_value_1count import RemoteValue1Count
 from .remote_value_climate_mode import (
     RemoteValueBinaryHeatCool,
@@ -25,6 +25,7 @@ from .remote_value_temp import RemoteValueTemp
 from .remote_value_updown import RemoteValueUpDown
 
 __all__ = [
+    "GroupAddressesType",
     "RemoteValue",
     "RemoteValue1Count",
     "RemoteValueBinaryHeatCool",
