@@ -3,30 +3,28 @@ Module for managing an RGBW remote value.
 
 DPT 251.600.
 """
-from typing import TYPE_CHECKING, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Tuple, Union
 
 from xknx.dpt import DPTArray, DPTBinary
 from xknx.exceptions import ConversionError
 
-from .remote_value import AsyncCallbackType, RemoteValue
+from .remote_value import AsyncCallbackType, GroupAddressesType, RemoteValue
 
 if TYPE_CHECKING:
-    from xknx.telegram.address import GroupAddressableType
     from xknx.xknx import XKNX
 
 
-class RemoteValueColorRGBW(RemoteValue[DPTArray]):
+class RemoteValueColorRGBW(RemoteValue[DPTArray, Tuple[int, int, int, int]]):
     """Abstraction for remote value of KNX DPT 251.600 (DPT_Color_RGBW)."""
 
     def __init__(
         self,
         xknx: "XKNX",
-        group_address: Optional["GroupAddressableType"] = None,
-        group_address_state: Optional["GroupAddressableType"] = None,
+        group_address: Optional[GroupAddressesType] = None,
+        group_address_state: Optional[GroupAddressesType] = None,
         device_name: Optional[str] = None,
         feature_name: str = "Color RGBW",
         after_update_cb: Optional[AsyncCallbackType] = None,
-        passive_group_addresses: Optional[List["GroupAddressableType"]] = None,
     ):
         """Initialize remote value of KNX DPT 251.600 (DPT_Color_RGBW)."""
         # pylint: disable=too-many-arguments
@@ -37,9 +35,8 @@ class RemoteValueColorRGBW(RemoteValue[DPTArray]):
             device_name=device_name,
             feature_name=feature_name,
             after_update_cb=after_update_cb,
-            passive_group_addresses=passive_group_addresses,
         )
-        self.previous_value: Tuple[int, ...] = (0, 0, 0, 0)
+        self.previous_value: Tuple[int, int, int, int] = (0, 0, 0, 0)
 
     def payload_valid(
         self, payload: Optional[Union[DPTArray, DPTBinary]]
@@ -104,17 +101,17 @@ class RemoteValueColorRGBW(RemoteValue[DPTArray]):
             return DPTArray(list(rgbw) + [0x00] + list(value[4:]))
         return DPTArray(value)
 
-    def from_knx(self, payload: DPTArray) -> Tuple[int, ...]:
+    def from_knx(self, payload: DPTArray) -> Tuple[int, int, int, int]:
         """
         Convert current payload to value. Always 4 byte (RGBW).
 
         If one element is invalid, use the previous value. All previous element
         values are initialized to 0.
         """
-        _result = []
+        _result = list(self.previous_value)
         for i in range(0, len(payload.value) - 2):
-            valid = (payload.value[5] & (0x08 >> i)) != 0  # R,G,B,W value valid?
-            _result.append(payload.value[i] if valid else self.previous_value[i])
-        result = tuple(_result)
+            if payload.value[5] & (0x08 >> i):  # R,G,B,W value valid?
+                _result[i] = payload.value[i]
+        result = (_result[0], _result[1], _result[2], _result[3])
         self.previous_value = result
         return result
