@@ -103,7 +103,7 @@ class APCI(ABC):
     This base class is only the interface for the derived classes.
     """
 
-    code: ClassVar[Union[APCIService, APCIUserService, APCIExtendedService]] = cast(
+    CODE: ClassVar[Union[APCIService, APCIUserService, APCIExtendedService]] = cast(
         APCIService, None
     )
 
@@ -211,7 +211,7 @@ class GroupValueRead(APCI):
     Does not have any payload.
     """
 
-    code = APCIService.GROUP_READ
+    CODE = APCIService.GROUP_READ
 
     def calculated_length(self) -> int:
         """Get length of APCI payload."""
@@ -225,7 +225,7 @@ class GroupValueRead(APCI):
 
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        return encode_cmd_and_payload(self.code)
+        return encode_cmd_and_payload(self.CODE)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -239,7 +239,7 @@ class GroupValueWrite(APCI):
     Takes a value (DPT) as payload.
     """
 
-    code = APCIService.GROUP_WRITE
+    CODE = APCIService.GROUP_WRITE
 
     def __init__(self, value: Optional[Union[DPTBinary, DPTArray]] = None) -> None:
         """Initialize a new instance of GroupValueWrite."""
@@ -263,10 +263,10 @@ class GroupValueWrite(APCI):
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
         if isinstance(self.value, DPTBinary):
-            return encode_cmd_and_payload(self.code, encoded_payload=self.value.value)
+            return encode_cmd_and_payload(self.CODE, encoded_payload=self.value.value)
         if isinstance(self.value, DPTArray):
             return encode_cmd_and_payload(
-                self.code, appended_payload=bytes(self.value.value)
+                self.CODE, appended_payload=bytes(self.value.value)
             )
         raise TypeError()
 
@@ -282,7 +282,7 @@ class GroupValueResponse(APCI):
     Takes a value (DPT) as payload.
     """
 
-    code = APCIService.GROUP_RESPONSE
+    CODE = APCIService.GROUP_RESPONSE
 
     def __init__(self, value: Optional[Union[DPTBinary, DPTArray]] = None) -> None:
         """Initialize a new instance of GroupValueResponse."""
@@ -306,10 +306,10 @@ class GroupValueResponse(APCI):
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
         if isinstance(self.value, DPTBinary):
-            return encode_cmd_and_payload(self.code, encoded_payload=self.value.value)
+            return encode_cmd_and_payload(self.CODE, encoded_payload=self.value.value)
         if isinstance(self.value, DPTArray):
             return encode_cmd_and_payload(
-                self.code, appended_payload=bytes(self.value.value)
+                self.CODE, appended_payload=bytes(self.value.value)
             )
         raise TypeError()
 
@@ -325,7 +325,7 @@ class IndividualAddressWrite(APCI):
     Payload contains the serial number and (new) address of the device.
     """
 
-    code = APCIService.INDIVIDUAL_ADDRESS_WRITE
+    CODE = APCIService.INDIVIDUAL_ADDRESS_WRITE
 
     def __init__(
         self,
@@ -350,7 +350,7 @@ class IndividualAddressWrite(APCI):
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
         return encode_cmd_and_payload(
-            self.code, appended_payload=bytes(self.address.to_knx())
+            self.CODE, appended_payload=bytes(self.address.to_knx())
         )
 
     def __str__(self) -> str:
@@ -361,7 +361,7 @@ class IndividualAddressWrite(APCI):
 class IndividualAddressRead(APCI):
     """IndividualAddressRead service."""
 
-    code = APCIService.INDIVIDUAL_ADDRESS_READ
+    CODE = APCIService.INDIVIDUAL_ADDRESS_READ
 
     def calculated_length(self) -> int:
         """Get length of APCI payload."""
@@ -375,7 +375,7 @@ class IndividualAddressRead(APCI):
 
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        return encode_cmd_and_payload(self.code)
+        return encode_cmd_and_payload(self.CODE)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -390,7 +390,7 @@ class IndividualAddressResponse(APCI):
     response address.
     """
 
-    code = APCIService.INDIVIDUAL_ADDRESS_RESPONSE
+    CODE = APCIService.INDIVIDUAL_ADDRESS_RESPONSE
 
     def calculated_length(self) -> int:
         """Get length of APCI payload."""
@@ -404,7 +404,7 @@ class IndividualAddressResponse(APCI):
 
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        return encode_cmd_and_payload(self.code)
+        return encode_cmd_and_payload(self.CODE)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -418,7 +418,7 @@ class ADCRead(APCI):
     Payload contains the channel and number of samples to take.
     """
 
-    code = APCIService.ADC_READ
+    CODE = APCIService.ADC_READ
 
     def __init__(self, channel: int = 0, count: int = 0) -> None:
         """Initialize a new instance of ADCRead."""
@@ -440,7 +440,7 @@ class ADCRead(APCI):
         payload = struct.pack("!BB", self.channel, self.count)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=payload[0], appended_payload=payload[1:]
+            self.CODE, encoded_payload=payload[0], appended_payload=payload[1:]
         )
 
     def __str__(self) -> str:
@@ -455,7 +455,7 @@ class ADCResponse(APCI):
     Payload contains the channel, number of samples and value.
     """
 
-    code = APCIService.ADC_RESPONSE
+    CODE = APCIService.ADC_RESPONSE
 
     def __init__(self, channel: int = 0, count: int = 0, value: int = 0) -> None:
         """Initialize a new instance of ADCResponse."""
@@ -478,7 +478,7 @@ class ADCResponse(APCI):
         payload = struct.pack("!BBH", self.channel, self.count, self.value)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=payload[0], appended_payload=payload[1:]
+            self.CODE, encoded_payload=payload[0], appended_payload=payload[1:]
         )
 
     def __str__(self) -> str:
@@ -493,7 +493,7 @@ class MemoryRead(APCI):
     Payload indicates address (64 KiB) and count (1-63 bytes).
     """
 
-    code = APCIService.MEMORY_READ
+    CODE = APCIService.MEMORY_READ
 
     def __init__(self, address: int = 0, count: int = 0) -> None:
         """Initialize a new instance of MemoryRead."""
@@ -520,7 +520,7 @@ class MemoryRead(APCI):
         payload = struct.pack("!BH", self.count, self.address)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=payload[0], appended_payload=payload[1:]
+            self.CODE, encoded_payload=payload[0], appended_payload=payload[1:]
         )
 
     def __str__(self) -> str:
@@ -535,7 +535,7 @@ class MemoryWrite(APCI):
     Payload indicates address (64 KiB), count (1-63 bytes) and data.
     """
 
-    code = APCIService.MEMORY_WRITE
+    CODE = APCIService.MEMORY_WRITE
 
     def __init__(
         self, address: int = 0, count: int = 0, data: Optional[bytes] = None
@@ -572,7 +572,7 @@ class MemoryWrite(APCI):
         payload = struct.pack(f"!BH{size}s", self.count, self.address, self.data)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=payload[0], appended_payload=payload[1:]
+            self.CODE, encoded_payload=payload[0], appended_payload=payload[1:]
         )
 
     def __str__(self) -> str:
@@ -587,7 +587,7 @@ class MemoryResponse(APCI):
     Payload indicates address (64 KiB), count (1-63 bytes) and data.
     """
 
-    code = APCIService.MEMORY_RESPONSE
+    CODE = APCIService.MEMORY_RESPONSE
 
     def __init__(
         self, address: int = 0, count: int = 0, data: Optional[bytes] = None
@@ -624,7 +624,7 @@ class MemoryResponse(APCI):
         payload = struct.pack(f"!BH{size}s", self.count, self.address, self.data)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=payload[0], appended_payload=payload[1:]
+            self.CODE, encoded_payload=payload[0], appended_payload=payload[1:]
         )
 
     def __str__(self) -> str:
@@ -639,7 +639,7 @@ class DeviceDescriptorRead(APCI):
     Payload contains the descriptor.
     """
 
-    code = APCIService.DEVICE_DESCRIPTOR_READ
+    CODE = APCIService.DEVICE_DESCRIPTOR_READ
 
     def __init__(self, descriptor: int = 0) -> None:
         """Initialize a new instance of DeviceDescriptorRead."""
@@ -658,7 +658,7 @@ class DeviceDescriptorRead(APCI):
         if self.descriptor < 0 or self.descriptor >= 2 ** 6:
             raise ConversionError("Descriptor out of range.")
 
-        return encode_cmd_and_payload(self.code, encoded_payload=self.descriptor)
+        return encode_cmd_and_payload(self.CODE, encoded_payload=self.descriptor)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -672,7 +672,7 @@ class DeviceDescriptorResponse(APCI):
     Payload contains the descriptor and value.
     """
 
-    code = APCIService.DEVICE_DESCRIPTOR_RESPONSE
+    CODE = APCIService.DEVICE_DESCRIPTOR_RESPONSE
 
     def __init__(self, descriptor: int = 0, value: int = 0) -> None:
         """Initialize a new instance of DeviceDescriptorResponse."""
@@ -697,7 +697,7 @@ class DeviceDescriptorResponse(APCI):
         payload = struct.pack("!H", self.value)
 
         return encode_cmd_and_payload(
-            self.code, encoded_payload=self.descriptor, appended_payload=payload
+            self.CODE, encoded_payload=self.descriptor, appended_payload=payload
         )
 
     def __str__(self) -> str:
@@ -714,7 +714,7 @@ class Restart(APCI):
     Does not take any payload.
     """
 
-    code = APCIService.RESTART
+    CODE = APCIService.RESTART
 
     def calculated_length(self) -> int:
         """Get length of APCI payload."""
@@ -728,7 +728,7 @@ class Restart(APCI):
 
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        return encode_cmd_and_payload(self.code)
+        return encode_cmd_and_payload(self.CODE)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -742,7 +742,7 @@ class UserMemoryRead(APCI):
     Payload indicates address (1 MiB) and count (1-15 bytes).
     """
 
-    code = APCIUserService.USER_MEMORY_READ
+    CODE = APCIUserService.USER_MEMORY_READ
 
     def __init__(self, address: int = 0, count: int = 0) -> None:
         """Initialize a new instance of UserMemoryRead."""
@@ -772,7 +772,7 @@ class UserMemoryRead(APCI):
 
         payload = struct.pack("!BH", byte0, address)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -786,7 +786,7 @@ class UserMemoryWrite(APCI):
     Payload indicates address (1 MiB), count and data.
     """
 
-    code = APCIUserService.USER_MEMORY_WRITE
+    CODE = APCIUserService.USER_MEMORY_WRITE
 
     def __init__(
         self, address: int = 0, count: int = 0, data: Optional[bytes] = None
@@ -826,7 +826,7 @@ class UserMemoryWrite(APCI):
         size = len(self.data)
         payload = struct.pack(f"!BH{size}s", byte0, address, self.data)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -840,7 +840,7 @@ class UserMemoryResponse(APCI):
     Payload indicates address (1 MiB), count and data.
     """
 
-    code = APCIUserService.USER_MEMORY_RESPONSE
+    CODE = APCIUserService.USER_MEMORY_RESPONSE
 
     def __init__(
         self, address: int = 0, count: int = 0, data: Optional[bytes] = None
@@ -880,7 +880,7 @@ class UserMemoryResponse(APCI):
         size = len(self.data)
         payload = struct.pack(f"!BH{size}s", byte0, address, self.data)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -890,7 +890,7 @@ class UserMemoryResponse(APCI):
 class UserManufacturerInfoRead(APCI):
     """UserManufacturerInfoRead service."""
 
-    code = APCIUserService.USER_MANUFACTURER_INFO_READ
+    CODE = APCIUserService.USER_MANUFACTURER_INFO_READ
 
     def calculated_length(self) -> int:
         """Get length of APCI payload."""
@@ -905,7 +905,7 @@ class UserManufacturerInfoRead(APCI):
     def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
 
-        return encode_cmd_and_payload(self.code)
+        return encode_cmd_and_payload(self.CODE)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -915,7 +915,7 @@ class UserManufacturerInfoRead(APCI):
 class UserManufacturerInfoResponse(APCI):
     """UserManufacturerInfoResponse service."""
 
-    code = APCIUserService.USER_MANUFACTURER_INFO_RESPONSE
+    CODE = APCIUserService.USER_MANUFACTURER_INFO_RESPONSE
 
     def __init__(self, manufacturer_id: int = 0, data: Optional[bytes] = None) -> None:
         """Initialize a new instance of UserManufacturerInfoResponse."""
@@ -937,7 +937,7 @@ class UserManufacturerInfoResponse(APCI):
         """Serialize to KNX/IP raw data."""
         payload = struct.pack("!B2s", self.manufacturer_id, self.data)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -947,7 +947,7 @@ class UserManufacturerInfoResponse(APCI):
 class FunctionPropertyCommand(APCI):
     """FunctionPropertyCommand service."""
 
-    code = APCIUserService.FUNCTION_PROPERTY_COMMAND
+    CODE = APCIUserService.FUNCTION_PROPERTY_COMMAND
 
     def __init__(
         self, object_index: int = 0, property_id: int = 0, data: Optional[bytes] = None
@@ -979,7 +979,7 @@ class FunctionPropertyCommand(APCI):
             f"!BB{size}s", self.object_index, self.property_id, self.data
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -989,7 +989,7 @@ class FunctionPropertyCommand(APCI):
 class FunctionPropertyStateRead(APCI):
     """FunctionPropertyStateRead service."""
 
-    code = APCIUserService.FUNCTION_PROPERTY_STATE_READ
+    CODE = APCIUserService.FUNCTION_PROPERTY_STATE_READ
 
     def __init__(
         self, object_index: int = 0, property_id: int = 0, data: Optional[bytes] = None
@@ -1021,7 +1021,7 @@ class FunctionPropertyStateRead(APCI):
             f"!BB{size}s", self.object_index, self.property_id, self.data
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1031,7 +1031,7 @@ class FunctionPropertyStateRead(APCI):
 class FunctionPropertyStateResponse(APCI):
     """FunctionPropertyStateResponse service."""
 
-    code = APCIUserService.FUNCTION_PROPERTY_STATE_READ
+    CODE = APCIUserService.FUNCTION_PROPERTY_STATE_READ
 
     def __init__(
         self,
@@ -1075,7 +1075,7 @@ class FunctionPropertyStateResponse(APCI):
             self.data,
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1085,7 +1085,7 @@ class FunctionPropertyStateResponse(APCI):
 class AuthorizeRequest(APCI):
     """AuthorizeRequest service."""
 
-    code = APCIExtendedService.AUTHORIZE_REQUEST
+    CODE = APCIExtendedService.AUTHORIZE_REQUEST
 
     def __init__(self, key: int = 0) -> None:
         """Initialize a new instance of AuthorizeRequest."""
@@ -1103,7 +1103,7 @@ class AuthorizeRequest(APCI):
         """Serialize to KNX/IP raw data."""
         payload = struct.pack("!BI", 0, self.key)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1113,7 +1113,7 @@ class AuthorizeRequest(APCI):
 class AuthorizeResponse(APCI):
     """AuthorizeResponse service."""
 
-    code = APCIExtendedService.AUTHORIZE_RESPONSE
+    CODE = APCIExtendedService.AUTHORIZE_RESPONSE
 
     def __init__(self, level: int = 0) -> None:
         """Initialize a new instance of AuthorizeResponse."""
@@ -1131,7 +1131,7 @@ class AuthorizeResponse(APCI):
         """Serialize to KNX/IP raw data."""
         payload = struct.pack("!B", self.level)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1145,7 +1145,7 @@ class PropertyValueRead(APCI):
     Payload indicates object, property, count and start.
     """
 
-    code = APCIExtendedService.PROPERTY_VALUE_READ
+    CODE = APCIExtendedService.PROPERTY_VALUE_READ
 
     def __init__(
         self,
@@ -1188,7 +1188,7 @@ class PropertyValueRead(APCI):
             self.start_index,
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1207,7 +1207,7 @@ class PropertyValueWrite(APCI):
     Payload indicates object, property, count, start and data itself.
     """
 
-    code = APCIExtendedService.PROPERTY_VALUE_WRITE
+    CODE = APCIExtendedService.PROPERTY_VALUE_WRITE
 
     def __init__(
         self,
@@ -1248,7 +1248,7 @@ class PropertyValueWrite(APCI):
             self.data,
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def from_knx(self, raw: bytes) -> None:
         """Parse/deserialize from KNX/IP raw data."""
@@ -1287,7 +1287,7 @@ class PropertyValueResponse(APCI):
     the payload depends on the data.
     """
 
-    code = APCIExtendedService.PROPERTY_VALUE_RESPONSE
+    CODE = APCIExtendedService.PROPERTY_VALUE_RESPONSE
 
     def __init__(
         self,
@@ -1343,7 +1343,7 @@ class PropertyValueResponse(APCI):
             self.data,
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1362,7 +1362,7 @@ class PropertyValueResponse(APCI):
 class PropertyDescriptionRead(APCI):
     """PropertyDescriptionRead service."""
 
-    code = APCIExtendedService.PROPERTY_DESCRIPTION_READ
+    CODE = APCIExtendedService.PROPERTY_DESCRIPTION_READ
 
     def __init__(
         self, object_index: int = 0, property_id: int = 0, property_index: int = 0
@@ -1388,7 +1388,7 @@ class PropertyDescriptionRead(APCI):
             "!BBB", self.object_index, self.property_id, self.property_index
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1398,7 +1398,7 @@ class PropertyDescriptionRead(APCI):
 class PropertyDescriptionResponse(APCI):
     """PropertyDescriptionResponse service."""
 
-    code = APCIExtendedService.PROPERTY_DESCRIPTION_RESPONSE
+    CODE = APCIExtendedService.PROPERTY_DESCRIPTION_RESPONSE
 
     def __init__(
         self,
@@ -1449,7 +1449,7 @@ class PropertyDescriptionResponse(APCI):
             self.access,
         )
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1459,7 +1459,7 @@ class PropertyDescriptionResponse(APCI):
 class IndividualAddressSerialRead(APCI):
     """IndividualAddressSerialRead service."""
 
-    code = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_READ
+    CODE = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_READ
 
     def __init__(self, serial: Optional[bytes] = None) -> None:
         """Initialize a new instance of PropertyDescriptionRead."""
@@ -1483,7 +1483,7 @@ class IndividualAddressSerialRead(APCI):
 
         payload = struct.pack("!6s", self.serial)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1493,7 +1493,7 @@ class IndividualAddressSerialRead(APCI):
 class IndividualAddressSerialResponse(APCI):
     """IndividualAddressSerialResponse service."""
 
-    code = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_RESPONSE
+    CODE = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_RESPONSE
 
     def __init__(
         self,
@@ -1527,7 +1527,7 @@ class IndividualAddressSerialResponse(APCI):
         address_high, address_low = self.address.to_knx()
         payload = struct.pack("!6sBBH", self.serial, address_high, address_low, 0)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
@@ -1537,7 +1537,7 @@ class IndividualAddressSerialResponse(APCI):
 class IndividualAddressSerialWrite(APCI):
     """IndividualAddressSerialWrite service."""
 
-    code = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_WRITE
+    CODE = APCIExtendedService.INDIVIDUAL_ADDRESS_SERIAL_WRITE
 
     def __init__(
         self,
@@ -1571,7 +1571,7 @@ class IndividualAddressSerialWrite(APCI):
         address_high, address_low = self.address.to_knx()
         payload = struct.pack("!6sBBI", self.serial, address_high, address_low, 0)
 
-        return encode_cmd_and_payload(self.code, appended_payload=payload)
+        return encode_cmd_and_payload(self.CODE, appended_payload=payload)
 
     def __str__(self) -> str:
         """Return object as readable string."""
